const fs = require('fs')
const path = require('path')
const { reporter } = require('@openhat/cli-helpers')

const shellSource = path.dirname(
    require.resolve('@openhat/app-shell/package.json')
)
const shellAppDirname = 'src/ohApp'

const findYarnLock = (base) => {
    if (base === '/') {
        return null
    }

    const yarnLock = path.join(base, './yarn.lock')
    if (fs.existsSync(yarnLock)) {
        return yarnLock
    }
    return findYarnLock(path.dirname(base))
}

module.exports = (cwd = process.cwd()) => {
    const base = path.resolve(cwd)
    const paths = {
        babelConfig: path.join(__dirname, '../../config/babel.config.js'),
        configDefaultsApp: path.join(
            __dirname,
            '../../config/oh.config.app.js'
        ),
        configDefaultsLib: path.join(
            __dirname,
            '../../config/oh.config.lib.js'
        ),
        configDefaultsPWA: path.join(
            __dirname,
            '../../config/oh.pwa.config.js'
        ),
        jestConfigDefaults: path.join(__dirname, '../../config/jest.config.js'),
        readmeDefault: path.join(__dirname, '../../config/init.README.md'),

        shellSource,
        shellSourceEntrypoint: path.join(shellSource, 'src/App.js'),
        shellSourcePublic: path.join(shellSource, 'public'),

        base,
        package: path.join(base, './package.json'),
        yarnLock: findYarnLock(base),
        dotenv: path.join(base, './.env'),
        config: path.join(base, './oh.config.js'),
        readme: path.join(base, './README.md'),
        src: path.join(base, './src'),
        public: path.join(base, './public'),
        jestConfig: path.join(base, 'jest.config.js'),
        i18nStrings: path.join(base, './i18n'),
        i18nLocales: path.join(base, './src/locales'),

        oh: path.join(base, './.oh/'),
        appOutputFilename: 'App.js',
        shell: path.join(base, './.oh/shell'),
        shellSrc: path.join(base, './.oh/shell/src'),
        shellAppEntrypoint: path.join(base, './.oh/shell/src/App.js'),
        shellAppDirname,
        shellApp: path.join(base, `./.oh/shell/${shellAppDirname}`),
        shellPluginBundleEntrypoint: path.join(
            base,
            './.oh/shell/src/plugin.index.js'
        ),
        shellPluginEntrypoint: path.join(base, './.oh/shell/src/Plugin.js'),
        shellSrcServiceWorker: path.join(
            base,
            './.oh/shell/src/service-worker.js'
        ),
        shellPublic: path.join(base, './.oh/shell/public'),
        shellPublicPluginHtml: path.join(
            base,
            './.oh/shell/public/plugin.html'
        ),
        shellPublicServiceWorker: path.join(
            base,
            './.oh/shell/public/service-worker.js'
        ),
        shellPublicManifestWebapp: path.join(
            base,
            './.oh/shell/public/manifest.webapp'
        ),
        shellPublicManifestJson: path.join(
            base,
            './.oh/shell/public/manifest.json'
        ),
        shellPublicConfigJson: path.join(
            base,
            './.oh/shell/public/oh.config.json'
        ),
        shellBuildOutput: path.join(base, './.oh/shell/build'),
        shellBuildServiceWorker: path.join(
            base,
            './.oh/shell/build/service-worker.js'
        ),

        buildOutput: path.join(base, './build'),
        buildAppOutput: path.join(base, './build/app'),
        buildAppManifest: path.join(base, './build/app/manifest.webapp'),
        buildAppConfigJson: path.join(base, './build/app/oh.config.json'),
        buildAppBundleFile: '{name}-{version}.zip',
        buildAppBundleOutput: path.join(base, 'build', 'bundle'),
        buildAppBundle: path.join(
            base,
            'build',
            'bundle',
            '{name}-{version}.zip'
        ),
        buildLibBundleFile: '{name}-{version}.zip',
        buildLibBundleOutput: path.join(base),

        launchPath: 'index.html',
        pluginLaunchPath: 'plugin.html',
    }

    reporter.debug('PATHS', paths)

    return paths
}
